import { type PropertyValues, LitElement } from 'lit';
import { Player, PlayerEvent } from '../player';
declare const PlayerComponent_base: {
    new (...args: any[]): {
        player: Player;
        readonly renderer: import("../renderers").UniversalCanvas;
        readonly note: import("../parsers/BaseParser").BaseParser;
        readonly noteFormat: import("../parsers").FlipnoteFormat;
        readonly meta: import("../parsers").FlipnoteMeta;
        readonly duration: number;
        readonly layerVisibility: {
            [x: number]: boolean;
        };
        autoplay: boolean;
        el: Element;
        parserSettings: Partial<import("../parsers").KwzParserSettings>;
        supportedEvents: PlayerEvent[];
        audio: import("../webaudio").WebAudioPlayer;
        _src: any;
        _loop: boolean;
        _volume: number;
        _muted: boolean;
        _frame: number;
        _hasEnded: boolean;
        isNoteLoaded: boolean;
        events: import("../player").PlayerEventMap;
        playbackStartTime: number;
        playbackTime: number;
        playbackLoopId: number;
        showThumbnail: boolean;
        hasPlaybackStarted: boolean;
        isPlaying: boolean;
        wasPlaying: boolean;
        isSeeking: boolean;
        src: any;
        paused: boolean;
        currentFrame: number;
        currentTime: number;
        progress: number;
        volume: number;
        muted: boolean;
        loop: boolean;
        readonly framerate: number;
        readonly frameCount: number;
        readonly frameSpeed: number;
        readonly buffered: TimeRanges;
        readonly seekable: TimeRanges;
        readonly currentSrc: any;
        readonly videoWidth: number;
        readonly videoHeight: number;
        load(source: any): Promise<void>;
        reload(): Promise<void>;
        updateSettings(settings: Partial<import("../parsers").KwzParserSettings>): Promise<void>;
        closeNote(): void;
        openNote(note: import("../parsers/BaseParser").BaseParser): void;
        playbackLoop: (timestamp: number) => void;
        setCurrentTime(value: number): void;
        getCurrentTime(): number;
        getTimeCounter(): string;
        getFrameCounter(): string;
        setProgress(value: number): void;
        getProgress(): number;
        play(): Promise<void>;
        pause(): void;
        togglePlay(): void;
        getPaused(): boolean;
        getDuration(): number;
        getLoop(): boolean;
        setLoop(loop: boolean): void;
        toggleLoop(): void;
        setCurrentFrame(newFrameValue: number): void;
        nextFrame(): void;
        prevFrame(): void;
        lastFrame(): void;
        firstFrame(): void;
        thumbnailFrame(): void;
        startSeek(): void;
        seek(position: number): void;
        endSeek(): void;
        drawFrame(frameIndex: number): void;
        forceUpdate(): void;
        resize(width: number, height: number): void;
        setLayerVisibility(layer: number, value: boolean): void;
        getLayerVisibility(layer: number): boolean;
        toggleLayerVisibility(layerIndex: number): void;
        "__#25237@#playAudio"(): void;
        "__#25237@#stopAudio"(): void;
        toggleAudioEq(): void;
        setAudioEq(state: boolean): void;
        mute(): void;
        unmute(): void;
        setMuted(isMute: boolean): void;
        getMuted(): boolean;
        toggleMuted(): void;
        setVolume(volume: number): void;
        getVolume(): number;
        seekToNextFrame(): void;
        fastSeek(time: number): void;
        canPlayType(mediaType: string): "" | "probably" | "maybe";
        getVideoPlaybackQuality(): VideoPlaybackQuality;
        requestPictureInPicture(): void;
        captureStream(): void;
        onplay: () => void;
        onpause: () => void;
        oncanplay: () => void;
        oncanplaythrough: () => void;
        onseeking: () => void;
        onseeked: () => void;
        ondurationchange: () => void;
        onloop: () => void;
        onended: () => void;
        onvolumechange: (volume: number) => void;
        onprogress: (progress: number) => void;
        ontimeupdate: (time: number) => void;
        onframeupdate: (frameIndex: number) => void;
        onframenext: () => void;
        onframeprev: () => void;
        onframefirst: () => void;
        onframelast: () => void;
        onready: () => void;
        onload: () => void;
        onloadstart: () => void;
        onloadeddata: () => void;
        onloadedmetadata: () => void;
        onemptied: () => void;
        onclose: () => void;
        onerror: (err?: Error) => void;
        ondestroy: () => void;
        on(eventType: PlayerEvent | PlayerEvent[], listener: Function): void;
        off(eventType: PlayerEvent | PlayerEvent[], callback: Function): void;
        emit(eventType: PlayerEvent, ...args: any): void;
        clearEvents(): void;
        destroy(): Promise<void>;
        assertNoteLoaded(): void;
    };
} & typeof LitElement;
/**
 * @group Web Component
 * @internal
 */
export declare class PlayerComponent extends PlayerComponent_base {
    static get styles(): import("lit").CSSResult;
    controls: string;
    dsiLibrary: boolean;
    cropBorder: boolean;
    bgmPredictor: number;
    bgmStepIndex: number;
    sePredictors: string;
    seStepIndices: string;
    get width(): number | string;
    set width(value: number | string);
    get src(): any;
    set src(src: any);
    get autoplay(): boolean;
    set autoplay(value: boolean);
    private _width;
    private _cssWidth;
    private _progress;
    private _counter;
    private _frameCount;
    private _isLoading;
    private _isError;
    private _isPlaying;
    private _isMuted;
    private _volumeLevel;
    private playerCanvasWrapper;
    private _isPlayerAvailable;
    private _playerSrc;
    private _resizeObserver;
    private _keysDown;
    private _counterMode;
    constructor();
    /**
     * @internal
     */
    render(): import("lit-html").TemplateResult<1>;
    /**
     * @internal
     */
    renderControls(): import("lit-html").TemplateResult<1>;
    /**
     * @internal
     */
    firstUpdated(changedProperties: PropertyValues): void;
    /**
     * @internal
     */
    disconnectedCallback(): void;
    private updateSettingsFromProps;
    private parseListProp;
    private updateCanvasSize;
    private handleResize;
    private handleKeyInputDown;
    private handleKeyInputUp;
    private handlePlayToggle;
    private handleMuteToggle;
    private handleProgressSliderChange;
    private handleProgressSliderInputStart;
    private handleProgressSliderInputEnd;
    private handleVolumeBarChange;
    private handleCounterClick;
}
export {};
