/// <reference types="node" />
export declare abstract class EncoderBase {
    mimeType: string;
    dataUrl: string;
    /**
     * Returns the file data as an {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/ArrayBuffer | ArrayBuffer}.
     */
    abstract getArrayBuffer(): ArrayBuffer;
    /**
     * Returns the file data as a NodeJS {@link https://nodejs.org/api/buffer.html | Buffer}.
     *
     * > Note: This method does not work outside of NodeJS environments.
     */
    getBuffer(): Buffer;
    /**
     * Returns the file data as a {@link https://developer.mozilla.org/en-US/docs/Web/API/Blob | Blob}.
     */
    getBlob(): Blob;
    /**
     * Returns the file data as an {@link https://developer.mozilla.org/en-US/docs/Web/API/URL/createObjectURL | Object URL}.
     *
     * > Note: This method does not work outside of browser environments.
     */
    getUrl(): string;
    /**
     * Revokes this file's {@link https://developer.mozilla.org/en-US/docs/Web/API/URL/createObjectURL | Object URL} if one has been created, use this when the url created with {@link getUrl} is no longer needed, to preserve memory.
     *
     * > Note: This method does not work outside of browser environments.
     */
    revokeUrl(): void;
}
