/**
 * PPM filenames can be decoded and broken down into different fields. This object represents a unpacked PPM filename.
 */
export interface FlipnotePpmUnpackedFilename {
    /** DSi MAC address suffix as hex, e.g. `AABBCC` */
    macSuffix: string;
    /** Random 5-digit hex string */
    random1: string;
    /** Random 8-digit hex string */
    random2: string;
    /** Number of edits */
    edits: number;
}
/**
 * Determines if a string matches the PPM filename format.
 */
export declare const isPpmFilename: (filename: string) => boolean;
/**
 * Does the same thing as {@link isPpmFilename}, expect it only matches "basic" filenames, without the checksum character that is added when saving a Flipnote to the filesystem.
 */
export declare const isPpmBasicFilename: (filename: string) => boolean;
/**
 *
 */
export declare const ppmFilenameCalculateCheckDigit: (filename: string) => string;
/**
 *
 */
export declare const ppmFilenameDecode: (filename: string) => FlipnotePpmUnpackedFilename;
/**
 *
 */
export declare const ppmFilenameEncode: (filename: FlipnotePpmUnpackedFilename) => string;
