import { FlipnoteRegion } from '../types';
/**
 * Indicates whether the input is a valid Flipnote Studio or Flipnote Studio 3D user ID.
 */
export declare const isFsid: (fsid: string) => boolean;
/**
 * Get the region for any valid Flipnote Studio or Flipnote Studio 3D user ID
 */
export declare const getFsidRegion: (fsid: string) => FlipnoteRegion;
/**
 * Convert a PPM Flipnote Studio ID to the format used by KWZ Flipnote Studio IDs (as seen in Nintendo DSi Library Flipnotes).
 * Will return `null` if the conversion could not be made.
 *
 * :::tip
 * KWZ Flipnote Studio IDs contain an extra two characters at the beginning.
 * It is not possible to resolve these from a PPM Flipnote Studio ID.
 * :::
*/
export declare const ppmFsidToKwzFsidSuffix: (fsid: string) => string;
/**
 * Convert a PPM Flipnote Studio ID to an array of all possible matching KWZ Flipnote Studio IDs (as seen in Nintendo DSi Library Flipnotes).
 * Will return `null` if the conversion could not be made.
 */
export declare const ppmFsidToPossibleKwzFsids: (fsid: string) => string[];
/**
 * Convert a KWZ Flipnote Studio ID (from a Nintendo DSi Library Flipnote) to the format used by PPM Flipnote Studio IDs.
 * Will return `null` if the conversion could not be made.
 */
export declare const kwzFsidToPpmFsid: (fsid: string) => string;
