import { CanvasInterface, CanvasStereoscopicMode } from './CanvasInterface';
import type { Flipnote } from '../parsers';
/**
 * Setup options for {@link Html5Canvas}
 */
export interface Html5CanvasOptions {
    /**
     * Use DPI scaling
     */
    useDpi: boolean;
    /**
     * Use image smoothing
     */
    useSmoothing: boolean;
}
/**
 * Flipnote renderer for the [HTML5 2D canvas API](https://developer.mozilla.org/en-US/docs/Web/API/CanvasRenderingContext2D)
 */
export declare class Html5Canvas implements CanvasInterface {
    #private;
    static defaultOptions: Html5CanvasOptions;
    static isSupported(): boolean;
    /**
     *
     */
    note: Flipnote;
    /**
     * Canvas HTML element being used as a rendering surface
     */
    canvas: HTMLCanvasElement;
    /**
     * Rendering context
     */
    ctx: CanvasRenderingContext2D;
    /**
     * View width (CSS pixels)
     */
    width: number;
    /**
     * View height (CSS pixels)
     */
    height: number;
    /**
     * Backing canvas width (real pixels)
     * Note that this factors in device pixel ratio, so it may not reflect the size of the canvas in CSS pixels
    */
    dstWidth: number;
    /**
     * Backing canvas height (real pixels)
     * Note that this factors in device pixel ratio, so it may not reflect the size of the canvas in CSS pixels
    */
    dstHeight: number;
    /**
     *
     */
    srcWidth: number;
    /**
     *
     */
    srcHeight: number;
    /**
     *
     */
    frameIndex: number;
    /**
     *
     */
    supportedStereoscopeModes: CanvasStereoscopicMode[];
    /**
     *
     */
    stereoscopeMode: CanvasStereoscopicMode;
    /**
     *
     */
    stereoscopeStrength: number;
    constructor(parent: Element, width: number, height: number, options?: Partial<Html5CanvasOptions>);
    /**
     * Resize the canvas surface
     * @param width - New canvas width, in CSS pixels
     * @param height - New canvas height, in CSS pixels
     *
     * The ratio between `width` and `height` should be 3:4 for best results
     */
    setCanvasSize(width: number, height: number): void;
    /**
     */
    setNote(note: Flipnote): void;
    /**
     * Clear the canvas
     * @param color optional RGBA color to use as a background color
     */
    clear(color?: [number, number, number, number]): void;
    drawFrame(frameIndex: number): void;
    requestStereoScopeMode(mode: CanvasStereoscopicMode): void;
    forceUpdate(): void;
    getDataUrl(type?: string, quality?: any): string;
    getBlob(type?: string, quality?: any): Promise<Blob>;
    destroy(): void;
}
