/**
 * @internal
 */
export declare const enum SeekOrigin {
    Begin = 0,
    Current = 1,
    End = 2
}
/**
 * Wrapper around the DataView API to keep track of the offset into the data,
 * also provides some utils for reading ascii strings etc.
 * @internal
 */
export declare class DataStream {
    /**
    * @internal
    */
    buffer: ArrayBufferLike;
    /**
    * @internal
    */
    pointer: number;
    /**
    * @internal
    */
    data: DataView;
    constructor(buffer: ArrayBufferLike);
    /**
     * Returns the data as an Uint8Array of bytes.
     */
    get bytes(): Uint8Array;
    /**
     * Returns the total number of bytes in the data.
     */
    get numBytes(): number;
    /**
     * @internal
     */
    seek(offset: number, whence?: SeekOrigin): void;
    /**
     * @internal
     */
    readUint8(): number;
    /**
     * @internal
     */
    writeUint8(value: number): void;
    /**
     * @internal
     */
    readInt8(): number;
    /**
     * @internal
     */
    writeInt8(value: number): void;
    /**
     * @internal
     */
    readUint16(littleEndian?: boolean): number;
    /**
     * @internal
     */
    writeUint16(value: number, littleEndian?: boolean): void;
    /**
     * @internal
     */
    readInt16(littleEndian?: boolean): number;
    /**
     * @internal
     */
    writeInt16(value: number, littleEndian?: boolean): void;
    /**
     * @internal
     */
    readUint32(littleEndian?: boolean): number;
    /**
     * @internal
     */
    writeUint32(value: number, littleEndian?: boolean): void;
    /**
     * @internal
     */
    readInt32(littleEndian?: boolean): number;
    /**
     * @internal
     */
    writeInt32(value: number, littleEndian?: boolean): void;
    /**
     * @internal
     */
    readBytes(count: number): Uint8Array;
    /**
     * @internal
     */
    writeBytes(bytes: number[] | Uint8Array): void;
    /**
     * @internal
     */
    readHex(count: number, reverse?: boolean): string;
    /**
     * @internal
     */
    readChar(): string;
    /**
     * @internal
     */
    readWideChar(): string;
    /**
     * @internal
     */
    readChars(count: number): string;
    /**
     * @internal
     */
    writeChars(string: string): void;
    /**
     * @internal
     */
    readWideChars(count: number): string;
    end(): boolean;
}
